=begin
	load 'TT_Lib\FileW.rb'
	FileW.exist?('C:\Test ')
=end

require 'TT_Lib/WinEx.rb'
require 'TT_Lib/FileTestW.rb'

# Calls the Unicode (wide) versions of the Windows API's file functions.
#
# It's a subclass of the standard +File+ class that only overrides the
# methods when it's run on a Windows system. Otherwise it functions as
# a normal +File+ class.
# File methods not re-implemented will behave as normal - trying to call
# the ASCII Windows API.
class FileW < File

	# Override the methods only on PC systems.
	if WinEx::IS_PC
	
	# Include the FileTestW methods as class methods.
	extend FileTestW
	
	# * +file_name+ --- UTF-8 +String+
	def self.atime(file_name)
		file_name = WinEx::FileSystem::normalize_w(file_name)
		return WinEx::FileSystem.get_file_data(file_name).last_access_time
	end
	
	# * +file_name+ --- UTF-8 +String+
	# * +suffix+ --- UTF-8 +String+
	def self.basename(file_name, suffix = nil)
		# (!) Verify
		basename = file_name.split('/').last
		unless suffix.nil?
			len = suffix.length
			basename[-len, len] = '' if basename[-len, len] == suffix
		end
		return basename
	end
	
	# * +from+ --- UTF-8 +String+
	# * +to+ --- UTF-8 +String+
	def self.catname(from, to)
		if self.directory?(to)
			# (!) Normalize file_name
			return self::join( to.sub(%r([/\\]$), ''), self.basename(from) )
		else
			return to
		end
	end
	
	# * +file_name+ --- UTF-8 +String+
	def self.ctime(file_name)
		file_name = WinEx::FileSystem::normalize_w(file_name)
		return WinEx::FileSystem.get_file_data(file_name).creation_time
	end
	
	def self.join(*args)
		# http://www.ruby-forum.com/topic/50137
		return args.join(self::SEPARATOR)
	end
	
	# * +file_name+ --- UTF-8 +String+
	def self.mtime(file_name)
		file_name = WinEx::FileSystem::normalize_w(file_name)
		return WinEx::FileSystem.get_file_data(file_name).last_write_time
	end
	
	end # if WinEx::IS_PC
	
end # class FileW