#-----------------------------------------------------------------------------
#
# Thomas Thomassen
# thomas[at]thomthom[dot]net
#
#-----------------------------------------------------------------------------

require 'sketchup.rb'
require 'TT_Lib/core.rb'
require 'TT_Lib/json.rb'

#-----------------------------------------------------------------------------

module TT_Lib

 # Reads .ini files into +TT_Lib::JSON+ objects.
 #
 # @see TT_Lib::JSON
 #
 # @since 1.0.0
 class Config_Ini < TT_Lib::JSON
	
	# Create new object with path to config file.
	#
	# @param [String] ini_file path to .ini file to read.
	#
	# @since 1.0.0
	def initialize(ini_file)
		# Current working section
		section = self
		
		# Read the file into an array of lines
		file = File.new(ini_file, 'r')
		lines = file.readlines
		file.close
		
		# Process lines
		lines.each { |line|
			# Skip comments
			next if line.strip.match(/^;.*/)
			
			# Sections
			if title = line.strip.match(/^\[(\w+)\]$/)
				title = title[1]
				self[title] = TT_Lib::JSON.new
				section = self[title]
				next
			end
			
			# Try to extract key-value data
			data = line.split('=')
			# Silently ignore anything that isn't a key-value pair.
			next unless data.length == 2
			
			# Clean up data
			data.each { |item|
				item.strip!
			}
			key, value = data
			
			# Interpret boolean data types
			value = ( %w(true, yes,  on, 1).include?(value) ) ? true  : value
			value = ( %w(false, no, off, 0).include?(value) ) ? false : value
			# Interpret float data types
			value = ( value.match(/^[\d]+[\.][\d]+$/) ) ? value.to_f : value if value.is_a?(String)
			# Interpret integer data types
			value = ( value.match(/^[\d]+$/) ) ? value.to_i : value if value.is_a?(String)
			
			# Add data to our hash
			section[key] = value
		}
	end

 end # class Config_Ini
end # module TT_Lib