#-----------------------------------------------------------------------------
#
# Thomas Thomassen
# thomas[at]thomthom[dot]net
#
#-----------------------------------------------------------------------------

require 'sketchup.rb'
require 'TT_Lib/core.rb'

#-----------------------------------------------------------------------------

module TT_Lib

 # @since 1.2.0
 module Cursor
	
	# Path to the cursor resources.
	PATH = TT_Lib::PATH + 'cursors/'
	
	# Definitions of cursor resources.
	# :symbol_id => ['filename.png', x, y]
	@cursors = {
		:default => 0,
		:offset => ['offset.png', 8, 6],
		:offset_invalid => ['offset_invalid.png', 8, 6],
		:dropper => ['dropper.png', 2, 29],
		:dropper_invalid => ['dropper_invalid.png', 2, 29]
	}
	
	# Creates cursor ids for the requested cursor +id+. Cursors are created on demand and
	# reused to save resources.
	#
	# Valid +id+ arguments
	# * +:default+
	# * +:offset+
	# * +:offset_invalid+
	#
	# @param [Symbol] id
	#
	# @return [Integer, nil] +Integer+ of a cursor resource uon success, +nil+ upon failure.
	#
	# @since 1.2.0
	def self.get_id(id)
		return nil unless @cursors.key?(id)
		# Load cursors on demand
		if @cursors[id].is_a?(Array)
			cursor_path, x, y = @cursors[id]
			@cursors[id] = UI.create_cursor(PATH + cursor_path, x, y)
		end
		return @cursors[id]
	end
 
 end # module Cursor
end # module TT_Lib